# Interpolation flags
INTER_AUTO: int = -1
INTER_NEAREST: int = 0
INTER_LINEAR: int = 1
INTER_CUBIC: int = 2
INTER_AREA: int = 3
INTER_LANCZOS4: int = 4
INTER_LANCZOS2: int = 10
INTER_LANCZOS3: int = 11
INTER_MITCHELL: int = 21
INTER_CATMULL_ROM: int = 22
INTER_B_SPLINE: int = 23

# JPEG encoding parameters
IMWRITE_JPEG_QUALITY: int = 1
IMWRITE_JPEG_PROGRESSIVE: int = 2
IMWRITE_JPEG_OPTIMIZE: int = 3
IMWRITE_JPEG_RST_INTERVAL: int = 4
IMWRITE_JPEG_LUMA_QUALITY: int = 5
IMWRITE_JPEG_CHROMA_QUALITY: int = 6
IMWRITE_JPEG_SAMPLING_FACTOR: int = 64

# PNG encoding parameters
IMWRITE_PNG_COMPRESSION: int = 16
IMWRITE_PNG_STRATEGY: int = 17
IMWRITE_PNG_BILEVEL: int = 18
IMWRITE_PNG_FILTER: int = 19

# PNG strategy options
IMWRITE_PNG_STRATEGY_DEFAULT: int = 0
IMWRITE_PNG_STRATEGY_FILTERED: int = 1
IMWRITE_PNG_STRATEGY_HUFFMAN_ONLY: int = 2
IMWRITE_PNG_STRATEGY_RLE: int = 3
IMWRITE_PNG_STRATEGY_FIXED: int = 4

# PNG filter options
IMWRITE_PNG_FILTER_NONE: int = 0
IMWRITE_PNG_FILTER_SUB: int = 1
IMWRITE_PNG_FILTER_UP: int = 2
IMWRITE_PNG_FILTER_AVG: int = 3
IMWRITE_PNG_FILTER_PAETH: int = 4

# TIFF encoding parameters
IMWRITE_TIFF_RESUNIT: int = 256
IMWRITE_TIFF_XDPI: int = 257
IMWRITE_TIFF_YDPI: int = 258
IMWRITE_TIFF_COMPRESSION: int = 259

# TIFF compression options
IMWRITE_TIFF_COMPRESSION_NONE: int = 1
IMWRITE_TIFF_COMPRESSION_CCITTRLE: int = 2
IMWRITE_TIFF_COMPRESSION_CCITTFAX3: int = 3
IMWRITE_TIFF_COMPRESSION_CCITTFAX4: int = 4
IMWRITE_TIFF_COMPRESSION_LZW: int = 5
IMWRITE_TIFF_COMPRESSION_JPEG: int = 7
IMWRITE_TIFF_COMPRESSION_DEFLATE: int = 8
IMWRITE_TIFF_COMPRESSION_ADOBE_DEFLATE: int = 32946

# EXR encoding parameters
IMWRITE_EXR_TYPE: int = 48
IMWRITE_EXR_COMPRESSION: int = 49

# EXR type options
IMWRITE_EXR_TYPE_HALF: int = 1
IMWRITE_EXR_TYPE_FLOAT: int = 2

# EXR compression options
IMWRITE_EXR_COMPRESSION_NONE: int = 0
IMWRITE_EXR_COMPRESSION_RLE: int = 1
IMWRITE_EXR_COMPRESSION_ZIPS: int = 2
IMWRITE_EXR_COMPRESSION_ZIP: int = 3
IMWRITE_EXR_COMPRESSION_PIZ: int = 4
IMWRITE_EXR_COMPRESSION_PXR24: int = 5
IMWRITE_EXR_COMPRESSION_B44: int = 6
IMWRITE_EXR_COMPRESSION_B44A: int = 7
IMWRITE_EXR_COMPRESSION_DWAA: int = 8
IMWRITE_EXR_COMPRESSION_DWAB: int = 9
